@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.47 2004/10/22 14:10:36 davyd Exp $ */
+/* $Id: gweather-dialog.c,v 1.50 2005/01/09 05:19:16 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -139,6 +139,8 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   GtkWidget *cond_vis_lbl;
   GtkWidget *cond_dew_lbl;
   GtkWidget *cond_apparent_lbl;
+  GtkWidget *cond_sunrise_lbl;
+  GtkWidget *cond_sunset_lbl;
   GtkWidget *cond_frame_alignment;
   GtkWidget *current_note_lbl;
   GtkWidget *forecast_note_lbl;
@@ -185,7 +187,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_container_add (GTK_CONTAINER (weather_notebook), cond_hbox);
   gtk_container_set_border_width (GTK_CONTAINER (cond_hbox), 4);
 
-  cond_table = gtk_table_new (11, 2, FALSE);
+  cond_table = gtk_table_new (13, 2, FALSE);
   gtk_widget_show (cond_table);
   gtk_box_pack_start (GTK_BOX (cond_hbox), cond_table, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (cond_table), 12);
@@ -280,6 +282,22 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_label_set_justify (GTK_LABEL (cond_vis_lbl), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (cond_vis_lbl), 0, 0.5);
 
+  cond_sunrise_lbl = gtk_label_new (_("Sunrise:"));
+  gtk_widget_show (cond_sunrise_lbl);
+  gtk_table_attach (GTK_TABLE (cond_table), cond_sunrise_lbl, 0, 1, 11, 12,
+                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_justify (GTK_LABEL (cond_sunrise_lbl), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (cond_sunrise_lbl), 0, 0.5);
+
+  cond_sunset_lbl = gtk_label_new (_("Sunset:"));
+  gtk_widget_show (cond_sunset_lbl);
+  gtk_table_attach (GTK_TABLE (cond_table), cond_sunset_lbl, 0, 1, 12, 13,
+                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_justify (GTK_LABEL (cond_sunset_lbl), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (cond_sunset_lbl), 0, 0.5);
+
   gw_applet->cond_location = gtk_label_new ("");
   gtk_widget_show (gw_applet->cond_location);
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_location, 1, 2, 0, 1,
@@ -379,6 +397,24 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_vis), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_vis), 0, 0.5);
 
+  gw_applet->cond_sunrise = gtk_label_new ("");
+  gtk_widget_show (gw_applet->cond_sunrise);
+  gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_sunrise, 1, 2, 11, 12,
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_sunrise), TRUE);
+  gtk_label_set_justify (GTK_LABEL (gw_applet->cond_sunrise), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_sunrise), 0, 0.5);
+
+  gw_applet->cond_sunset = gtk_label_new ("");
+  gtk_widget_show (gw_applet->cond_sunset);
+  gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_sunset, 1, 2, 12, 13,
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_sunset), TRUE);
+  gtk_label_set_justify (GTK_LABEL (gw_applet->cond_sunset), GTK_JUSTIFY_LEFT);
+  gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_sunset), 0, 0.5);
+
   cond_frame_alignment = gtk_alignment_new (0.5, 0, 1, 0);
   gtk_widget_show (cond_frame_alignment);
   gtk_box_pack_end (GTK_BOX (cond_hbox), cond_frame_alignment, FALSE, FALSE, 0);
@@ -459,6 +495,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
       set_access_namedesc (radar_link_btn, _("Visit Weather.com"), _("Click to Enter Weather.com"));
       gtk_widget_set_usize(radar_link_btn, 450, -2);
       gtk_widget_show (radar_link_btn);
+      if (!panel_applet_gconf_get_bool (gw_applet->applet, "use_custom_radar_url", NULL))
       gtk_container_add (GTK_CONTAINER (radar_link_alignment), radar_link_btn);
 
       gtk_signal_connect (GTK_OBJECT (radar_link_btn), "clicked",
@@ -539,6 +576,8 @@ void gweather_dialog_update (GWeatherApplet *gw_applet)
     gtk_label_set_text(GTK_LABEL(gw_applet->cond_wind), weather_info_get_wind(gw_applet->gweather_info));
     gtk_label_set_text(GTK_LABEL(gw_applet->cond_pressure), weather_info_get_pressure(gw_applet->gweather_info));
     gtk_label_set_text(GTK_LABEL(gw_applet->cond_vis), weather_info_get_visibility(gw_applet->gweather_info));
+    gtk_label_set_text(GTK_LABEL(gw_applet->cond_sunrise), weather_info_get_sunrise(gw_applet->gweather_info));
+    gtk_label_set_text(GTK_LABEL(gw_applet->cond_sunset), weather_info_get_sunset(gw_applet->gweather_info));
 
     /* Update forecast */
     if (gw_applet->gweather_pref.location->zone_valid) {
@@ -552,11 +591,15 @@ void gweather_dialog_update (GWeatherApplet *gw_applet)
     }
 
     /* Update radar map */
-    if (gw_applet->gweather_pref.radar_enabled) {
-        GdkPixmap *radar = weather_info_get_radar(gw_applet->gweather_info);
-        if (radar) {
-            gtk_image_set_from_pixmap (GTK_IMAGE (gw_applet->radar_image), 
-                                       radar, gw_applet->gweather_info->radar_mask);
+    if (gw_applet->gweather_pref.radar_enabled)
+    {
+        GdkPixbufAnimation *radar;
+	
+	radar = weather_info_get_radar (gw_applet->gweather_info);
+        if (radar)
+	{
+            gtk_image_set_from_animation (GTK_IMAGE (gw_applet->radar_image), 
+                                       radar);
         }
     }
 }
