@@ -107,7 +107,7 @@ static int gconfKbdConfigListenerId;
  * static common functions
  */
 static void
-_GSwitchItKbdConfigListReset (GSList ** plist)
+_GSwitchItConfigStringListReset (GSList ** plist)
 {
 	while (*plist != NULL) {
 		GSList *p = *plist;
@@ -274,8 +274,8 @@ _GSwitchItKbdConfigLayoutsAdd (GSwitchItKbdConfig * kbdConfig,
 }
 
 static void
-_GSwitchItKbdConfigCopyFromXklConfig (GSwitchItKbdConfig *
-				      kbdConfig, XklConfigRec * pdata)
+_GSwitchItKbdConfigCopyFromXklConfig (GSwitchItKbdConfig * kbdConfig,
+				      XklConfigRec * pdata)
 {
 	int i;
 	char **p, **p1;
@@ -325,8 +325,8 @@ _GSwitchItKbdConfigCopyFromXklConfig (GSwitchItKbdConfig *
 }
 
 static void
-_GSwitchItKbdConfigCopyToXklConfig (GSwitchItKbdConfig *
-				    kbdConfig, XklConfigRec * pdata)
+_GSwitchItKbdConfigCopyToXklConfig (GSwitchItKbdConfig * kbdConfig,
+				    XklConfigRec * pdata)
 {
 	int i;
 	pdata->model =
@@ -429,6 +429,7 @@ _GSwitchItKbdConfigLoadParams (GSwitchItKbdConfig * kbdConfig,
 		GSwitchItKbdConfigModelSet (kbdConfig, NULL);
 	} else {
 		GSwitchItKbdConfigModelSet (kbdConfig, pc);
+		g_free (pc);
 	}
 	XklDebug (150, "Loaded Kbd model: [%s]\n", kbdConfig->model);
 
@@ -451,6 +452,7 @@ _GSwitchItKbdConfigLoadParams (GSwitchItKbdConfig * kbdConfig,
 		_GSwitchItKbdConfigLayoutsAdd (kbdConfig, pl->data);
 		pl = pl->next;
 	}
+	_GSwitchItConfigStringListReset(&pl);
 
 	GSwitchItKbdConfigOptionsReset (kbdConfig);
 
@@ -472,6 +474,7 @@ _GSwitchItKbdConfigLoadParams (GSwitchItKbdConfig * kbdConfig,
 					       (const char *) pl->data);
 		pl = pl->next;
 	}
+	_GSwitchItConfigStringListReset(&pl);
 }
 
 static void
@@ -533,7 +536,7 @@ GSwitchItConfigTerm (GSwitchItConfig * config)
 }
 
 void
-GSwitchItConfigLoad (GSwitchItConfig * config)
+GSwitchItConfigLoadFromGConf (GSwitchItConfig * config)
 {
 	GError *gerror = NULL;
 
@@ -595,7 +598,7 @@ GSwitchItConfigLoad (GSwitchItConfig * config)
 }
 
 void
-GSwitchItConfigSave (GSwitchItConfig * config)
+GSwitchItConfigSaveToGConf (GSwitchItConfig * config)
 {
 	GConfChangeSet *cs;
 	GError *gerror = NULL;
@@ -710,7 +713,7 @@ GSwitchItKbdConfigTerm (GSwitchItKbdConfig * kbdConfig)
 }
 
 void
-GSwitchItKbdConfigLoad (GSwitchItKbdConfig * kbdConfig)
+GSwitchItKbdConfigLoadFromGConf (GSwitchItKbdConfig * kbdConfig)
 {
 	GError *gerror = NULL;
 
@@ -733,14 +736,14 @@ GSwitchItKbdConfigLoad (GSwitchItKbdConfig * kbdConfig)
 }
 
 void
-GSwitchItKbdConfigLoadSysBackup (GSwitchItKbdConfig * kbdConfig)
+GSwitchItKbdConfigLoadFromGConfBackup (GSwitchItKbdConfig * kbdConfig)
 {
 	_GSwitchItKbdConfigLoadParams (kbdConfig,
 				       GSWITCHIT_KBD_CONFIG_SYSBACKUP);
 }
 
 void
-GSwitchItKbdConfigLoadCurrent (GSwitchItKbdConfig * kbdConfig)
+GSwitchItKbdConfigLoadFromXCurrent (GSwitchItKbdConfig * kbdConfig)
 {
 	XklConfigRec data;
 	XklConfigRecInit (&data);
@@ -754,7 +757,7 @@ GSwitchItKbdConfigLoadCurrent (GSwitchItKbdConfig * kbdConfig)
 }
 
 void
-GSwitchItKbdConfigLoadInitial (GSwitchItKbdConfig * kbdConfig)
+GSwitchItKbdConfigLoadFromXInitial (GSwitchItKbdConfig * kbdConfig)
 {
 	XklConfigRec data;
 	XklConfigRecInit (&data);
@@ -783,7 +786,7 @@ GSwitchItKbdConfigEquals (GSwitchItKbdConfig * kbdConfig1,
 }
 
 void
-GSwitchItKbdConfigSave (GSwitchItKbdConfig * kbdConfig)
+GSwitchItKbdConfigSaveToGConf (GSwitchItKbdConfig * kbdConfig)
 {
 	GConfChangeSet *cs;
 	GError *gerror = NULL;
@@ -810,7 +813,7 @@ GSwitchItKbdConfigSave (GSwitchItKbdConfig * kbdConfig)
 }
 
 void
-GSwitchItKbdConfigSaveSysBackup (GSwitchItKbdConfig * kbdConfig)
+GSwitchItKbdConfigSaveToGConfBackup (GSwitchItKbdConfig * kbdConfig)
 {
 	GConfChangeSet *cs;
 	GError *gerror = NULL;
@@ -858,13 +861,13 @@ GSwitchItKbdConfigLayoutsAdd (GSwitchItKbdConfig * kbdConfig,
 void
 GSwitchItKbdConfigLayoutsReset (GSwitchItKbdConfig * kbdConfig)
 {
-	_GSwitchItKbdConfigListReset (&kbdConfig->layouts);
+	_GSwitchItConfigStringListReset (&kbdConfig->layouts);
 }
 
 void
 GSwitchItKbdConfigOptionsReset (GSwitchItKbdConfig * kbdConfig)
 {
-	_GSwitchItKbdConfigListReset (&kbdConfig->options);
+	_GSwitchItConfigStringListReset (&kbdConfig->options);
 }
 
 void
@@ -1098,7 +1101,7 @@ GSwitchItAppletConfigUpdateImages (GSwitchItAppletConfig * appletConfig,
 }
 
 void
-GSwitchItAppletConfigLoad (GSwitchItAppletConfig * appletConfig)
+GSwitchItAppletConfigLoadFromGConf (GSwitchItAppletConfig * appletConfig)
 {
 	GError *gerror = NULL;
 
@@ -1142,7 +1145,7 @@ GSwitchItAppletConfigLoad (GSwitchItAppletConfig * appletConfig)
 }
 
 void
-GSwitchItAppletConfigSave (GSwitchItAppletConfig * appletConfig)
+GSwitchItAppletConfigSaveToGConf (GSwitchItAppletConfig * appletConfig)
 {
 	GConfChangeSet *cs;
 	GError *gerror = NULL;
