@@ -85,11 +85,11 @@ static struct {
   gchar *filename;
   GdkPixbuf *pixbuf;
 } pix[] = {
-  { PIXDIR "/volume-mute.png",   NULL },
-  { PIXDIR "/volume-zero.png",   NULL },
-  { PIXDIR "/volume-min.png",    NULL },
-  { PIXDIR "/volume-medium.png", NULL },
-  { PIXDIR "/volume-max.png",    NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-mute.png",   NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-zero.png",   NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-min.png",    NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-medium.png", NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-max.png",    NULL },
   { NULL, NULL }
 };
 
@@ -331,7 +331,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
 
   /* menu - done here because bonobo is intialized now */
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet), 
-				     NULL,
+				     DATADIR,
 				     "GNOME_MixerApplet.xml",
 				     NULL, verbs, applet);
   component = panel_applet_get_popup_component (PANEL_APPLET (applet));
@@ -1002,25 +1002,21 @@ cb_verb (BonoboUIComponent *uic,
       g_error_free (error);
     }
   } else if (!strcmp (verbname, "About")) {
-    GtkWidget *about;
-    GdkPixbuf *pixbuf;
+	  
     const gchar *authors[] = { "Ronald Bultje <rbultje@ronald.bitfreak.net>",
 			     NULL };
 
-    pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-		    "gnome-mixer-applet", 48, 0, NULL);
-    
-    about = gnome_about_new (_("Volume Applet"),
-			     VERSION,
-			     "(c) 2004 Ronald Bultje",
-			     _("A GNOME/GStreamer-based volume control applet"),
-			     authors, NULL, NULL,
-			     pixbuf);
+    gtk_show_about_dialog (NULL,
+		"name",		_("Volume Applet"),
+		"version",	VERSION,
+		"copyright",	"\xC2\xA9 2004 Ronald Bultje",
+		"comments",	_("A GNOME/GStreamer-based volume control "
+				  "applet"),
+		"authors",	authors,
+		"translator-credits",	_("translator-credits"),
+		"logo-icon-name",	"gnome-mixer-applet",
+		NULL);
 
-    if (pixbuf)
-	    g_object_unref (pixbuf);
-
-    gtk_widget_show (about);
   } else if (!strcmp (verbname, "Pref")) {
     if (applet->prefs)
       return;
