@@ -42,7 +42,9 @@ about_cb (BonoboUIComponent *uic,
     static const gchar *authors[] =
     {
 		"Martin Baulig <martin@home-of-linux.org>",
-		"Todd Kulesza <fflewddur@dropline.net>\n",
+		"Todd Kulesza <fflewddur@dropline.net>",
+		"Benoît Dejean <benoit.dejean@placenet.org>",
+		"Davyd Madeley <davyd@madeley.id.au>",
 		NULL
     };
 
@@ -53,39 +55,19 @@ about_cb (BonoboUIComponent *uic,
 		NULL
     };
 
-    const gchar *translator_credits = _("translator_credits");
-
-    if (ma->about_dialog) {
-	gtk_window_set_screen (GTK_WINDOW (ma->about_dialog),
-			       gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
-
-	gtk_window_present (GTK_WINDOW (ma->about_dialog));
-	return;
-    }
-	
-    pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-		    "gnome-monitor", 48, 0, NULL);
-	
-    ma->about_dialog = gnome_about_new (_("System Monitor"), VERSION,
-					"(C) 1999 - 2002 The Free Software Foundation",
-					_("Released under the GNU General Public License.\n\n"
-					  "A system load monitor capable of displaying graphs for CPU, ram, and swap space use, plus network traffic."),
-					authors,
-					documenters,
-					strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-					pixbuf);
-
-    if (pixbuf) 
-	g_object_unref (pixbuf);
-  
-    gtk_window_set_screen (GTK_WINDOW (ma->about_dialog),
-			   gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
-    gtk_window_set_wmclass (GTK_WINDOW (ma->about_dialog), "system monitor",
-			    "System Monitor");
-    g_signal_connect (G_OBJECT (ma->about_dialog), "destroy",
-		      G_CALLBACK (gtk_widget_destroyed), &ma->about_dialog);
-
-    gtk_widget_show (ma->about_dialog);
+    gtk_show_about_dialog (NULL,
+	"name",		_("System Monitor"),
+	"version",	VERSION,
+	"copyright",	"\xC2\xA9 1999-2005 Free Software Foundation "
+			"and others",
+	"comments",	_("A system load monitor capable of displaying graphs "
+			"for CPU, ram, and swap space use, plus network "
+			"traffic."),
+	"authors",	authors,
+	"documenters",	documenters,
+	"translator-credits",	_("translator-credits"),
+	"logo-icon-name",	"gnome-monitor",
+	NULL);
 }
 
 static void
@@ -156,7 +138,7 @@ start_procman_cb (BonoboUIComponent *uic,
 	start_procman (ma);
 }
 
-void
+static void
 multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
 {
 	MultiloadApplet *ma = (MultiloadApplet *)data;
@@ -166,7 +148,7 @@ multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
 	return;
 }
 
-void
+static void
 multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 {
 	MultiloadApplet *ma = data;
@@ -175,36 +157,47 @@ multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 	return;
 }
 
-void
-multiload_change_background_cb(PanelApplet *a, PanelAppletBackgroundType type,
-				GdkColor *color, GdkPixmap *pixmap,
+static void
+multiload_change_background_cb (PanelApplet *a,
+				PanelAppletBackgroundType type,
+				GdkColor *color,
+				GdkPixmap *pixmap,
 				gpointer *data)
 {
-	MultiloadApplet *ma = (MultiloadApplet *)data;
-	GtkRcStyle *rc_style = gtk_rc_style_new ();
+	/* Taken from Trash Applet */
+	MultiloadApplet *ma = (MultiloadApplet *) data;
+	GtkRcStyle *rc_style;
+	GtkStyle *style;
+	
+	/* reset style */
+	gtk_widget_set_style (GTK_WIDGET (ma->applet), NULL);
+	rc_style = gtk_rc_style_new ();
+	gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+	g_object_unref (rc_style);
 
 	switch (type) {
-		case PANEL_PIXMAP_BACKGROUND:
-			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+		case PANEL_COLOR_BACKGROUND:
+			gtk_widget_modify_bg (GTK_WIDGET (ma->applet),
+					GTK_STATE_NORMAL, color);
 			break;
 
-		case PANEL_COLOR_BACKGROUND:
-			gtk_widget_modify_bg (GTK_WIDGET (ma->applet), GTK_STATE_NORMAL, color);
+		case PANEL_PIXMAP_BACKGROUND:
+			style = gtk_style_copy (GTK_WIDGET (ma->applet)->style);
+			if (style->bg_pixmap[GTK_STATE_NORMAL])
+				g_object_unref
+					(style->bg_pixmap[GTK_STATE_NORMAL]);
+			style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref
+				(pixmap);
+			gtk_widget_set_style (GTK_WIDGET (ma->applet), style);
 			break;
 
 		case PANEL_NO_BACKGROUND:
-			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
-			break;
-
 		default:
-			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
 			break;
 	}
-
-	gtk_rc_style_unref (rc_style);
 }
 
-void
+static void
 multiload_destroy_cb(GtkWidget *widget, gpointer data)
 {
 	gint i;
@@ -237,7 +230,7 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 	return;
 }
 
-gboolean
+static gboolean
 multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 {
 	MultiloadApplet *ma;
@@ -255,7 +248,8 @@ multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 	return TRUE;
 }
 
-gboolean
+#if 0
+static gboolean
 multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 {
 	MultiloadApplet *ma;
@@ -269,6 +263,7 @@ multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 		
 	return TRUE;
 }
+#endif /* 0 */
 
 static gboolean
 multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MultiloadApplet *ma)
@@ -276,7 +271,7 @@ multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, Multi
 	g_return_val_if_fail (event != NULL, FALSE);
 	g_return_val_if_fail (ma != NULL, FALSE);
 
-	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
+	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
 		start_procman (ma);
 		return TRUE;
 	}
@@ -332,6 +327,8 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		name = g_strdup(_("Swap Space"));
 	else if (!strncmp(g->name, "loadavg", strlen("loadavg")))
 		name = g_strdup(_("Load Average"));
+	else if (!strncmp (g->name, "diskload", strlen("diskload")))
+		name = g_strdup(_("Disk"));
 	else
 		name = g_strdup(_("Resource"));
 	
@@ -406,6 +403,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	ma->graphs[2] = netload_applet_new(ma->applet, NULL);
 	ma->graphs[3] = swapload_applet_new(ma->applet, NULL);
 	ma->graphs[4] = loadavg_applet_new(ma->applet, NULL);
+	ma->graphs[5] = diskload_applet_new(ma->applet, NULL);
 	
 	/* only start and display the graphs the user has turned on */
 
@@ -433,7 +431,7 @@ static const BonoboUIVerb multiload_menu_verbs [] = {
 };		
 
 /* create a box and stuff the load graphs inside of it */
-gboolean
+static gboolean
 multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
 	MultiloadApplet *ma;
@@ -453,7 +451,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
 	panel_applet_setup_menu_from_file (applet,
-					   NULL,
+					   DATADIR,
 					   "GNOME_MultiloadApplet.xml",
 					   NULL,
 					   multiload_menu_verbs,
